package de.intevation.flys.exports;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.title.TextTitle;

import de.intevation.artifacts.Artifact;

import de.intevation.flys.artifacts.WINFOArtifact;
import de.intevation.flys.artifacts.model.WQKms;


/**
 * An OutGenerator that generates discharge curves.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ComputedDischargeCurveGenerator extends DischargeCurveGenerator {

    /** The logger used in this generator.*/
    private static Logger logger =
        Logger.getLogger(ComputedDischargeCurveGenerator.class);


    public static final String I18N_CHART_TITLE =
        "chart.computed.discharge.curve.title";

    public static final String I18N_CHART_SUBTITLE =
        "chart.computed.discharge.curve.subtitle";

    public static final String I18N_YAXIS_LABEL =
        "chart.computed.discharge.curve.yaxis.label";

    public static final String I18N_CHART_TITLE_DEFAULT = "Abflusskurve";
    public static final String I18N_YAXIS_LABEL_DEFAULT = "W [NN + m]";


    @Override
    protected String getChartTitle() {
        return msg(I18N_CHART_TITLE, I18N_CHART_TITLE_DEFAULT);
    }


    @Override
    protected void addSubtitles(JFreeChart chart) {
        double[] dist  = getRange();

        Object[] args = new Object[] {
            getRiverName(),
            dist[0]
        };

        String subtitle = msg(I18N_CHART_SUBTITLE, "", args);
        chart.addSubtitle(new TextTitle(subtitle));
    }


    @Override
    protected String getYAxisLabel() {
        return msg(I18N_YAXIS_LABEL, I18N_YAXIS_LABEL_DEFAULT);
    }


    @Override
    public void doOut(Artifact artifact, String facet, Document attr) {
        logger.debug("ComputedDischargeCurveGenerator.doOut");

        WQKms wqkms = getData(artifact);

        int size = wqkms.size();

        double[][] data = new double[2][size];
        double[]   res  = new double[3];

        for (int i = 0; i < size; i++) {
            res = wqkms.get(i, res);

            data[0][i] = res[1];
            data[1][i] = res[0];
        }

        dataset.addSeries(getSeriesName(wqkms), data);
    }


    protected WQKms getData(Artifact artifact) {
        logger.debug("ComputedDischargeCurveGenerator.getData");

        WINFOArtifact winfoArtifact = (WINFOArtifact) artifact;

        return winfoArtifact.getComputedDischargeCurveData();
    }


    protected String getSeriesName(WQKms wqkms) {
        Object[] args = new Object[] {
            getRiverName(),
            wqkms.getName()
        };

        return msg(
            "chart.computed.discharge.curve.curve.label",
            "",
            args);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
